Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1766)

Unified Diff: chrome/browser/chromeos/file_system_provider/provided_file_system_interface.h

Issue 703123003: [fsp] Pass more detailed errors to the providing extension. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fixed a bug. Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/file_system_provider/provided_file_system_interface.h
diff --git a/chrome/browser/chromeos/file_system_provider/provided_file_system_interface.h b/chrome/browser/chromeos/file_system_provider/provided_file_system_interface.h
index 4e8c4b8d1a35ed4eec30bcaa17faf0df4f0fb70e..9395a648c631a6b22d55523d97303b9e441c9f15 100644
--- a/chrome/browser/chromeos/file_system_provider/provided_file_system_interface.h
+++ b/chrome/browser/chromeos/file_system_provider/provided_file_system_interface.h
@@ -198,14 +198,17 @@ class ProvidedFileSystemInterface {
const storage::AsyncFileUtil::StatusCallback& callback) = 0;
// Notifies about changes related to the watcher within the file system.
// Invoked by the file system implementation. Returns false if the
// notification arguments are malformed or the entry is not watched anymore.
// TODO(mtomasz): Replace [entry_path, recursive] with a watcher id.
- virtual bool Notify(const base::FilePath& entry_path,
- bool recursive,
- storage::WatcherManager::ChangeType change_type,
- scoped_ptr<ProvidedFileSystemObserver::Changes> changes,
- const std::string& tag) = 0;
+ virtual void Notify(
+ const base::FilePath& entry_path,
+ bool recursive,
+ storage::WatcherManager::ChangeType change_type,
+ scoped_ptr<ProvidedFileSystemObserver::Changes> changes,
+ const std::string& tag,
+ const storage::AsyncFileUtil::StatusCallback& callback) = 0;
// Returns a provided file system info for this file system.
virtual const ProvidedFileSystemInfo& GetFileSystemInfo() const = 0;
@@ -198,14 +198,17 @@ class ProvidedFileSystemInterface {
const storage::AsyncFileUtil::StatusCallback& callback) = 0;
// Notifies about changes related to the watcher within the file system.
- // Invoked by the file system implementation. Returns false if the
- // notification arguments are malformed or the entry is not watched anymore.
+ // Invoked by the file system implementation. Returns an error code via the
+ // callback if the notification arguments are malformed or the entry is not
+ // watched anymore. On success, returns base::File::FILE_OK.
// TODO(mtomasz): Replace [entry_path, recursive] with a watcher id.

Powered by Google App Engine
This is Rietveld 408576698